( cd usr/lib ; rm -rf libzita-alsa-pcmi.so )
( cd usr/lib ; ln -sf libzita-alsa-pcmi.so.0.6.1 libzita-alsa-pcmi.so )
( cd usr/lib ; rm -rf libzita-alsa-pcmi.so.0 )
( cd usr/lib ; ln -sf libzita-alsa-pcmi.so.0.6.1 libzita-alsa-pcmi.so.0 )
